#[repr(u8)]pub enum BlockState {
Included = 0,
Finalized = 1,
Discarded = 2,
DoesNotExist = 3,
}Expand description
Indicates what happened to a transaction after it was submitted.
The variants correspond to the states returned by the chain RPC when querying transaction status.
Variants
Included = 0
The transaction was included in a block but the block may still be re-orged out.
Finalized = 1
The block containing the transaction is finalized and immutable under normal circumstances.
Discarded = 2
The transaction was seen but ended up discarded (e.g. due to invalidation).
DoesNotExist = 3
The transaction could not be found on chain.